@@ -1,3 +1,9 @@
+#******************************************************************************
+# Copyright 1996-2013 United States Government as represented by the
+# Administrator of the National Aeronautics and Space Administration.
+# All Rights Reserved.
+#*****************************************************************************/
+
 package CDF;
 
 require Exporter;
@@ -348,6 +354,7 @@ use AutoLoader;
 	rVAR_NUMallocRECS_
 	rVAR_PADVALUE_
 	rVAR_RECORDS_
+	rVAR_RECORDS_RENUMBER_
 	rVAR_RECVARY_
 	rVAR_RESERVEPERCENT_
 	rVAR_SEQDATA_
@@ -413,6 +420,7 @@ use AutoLoader;
 	zVAR_RECINTERVAL_
 	zVAR_RECNUMBER_
 	zVAR_RECORDS_
+	zVAR_RECORDS_RENUMBER_
 	zVAR_RECVARY_
 	zVAR_RESERVEPERCENT_
 	zVAR_SEQDATA_
@@ -664,7 +672,9 @@ FCN: {
 		    $item == &zENTRY_ || $item == &zVAR_) {
 			$status = CDFlibnone($operation, $item);
 
-		} elsif ($item == &rVAR_RECORDS_ || $item == &zVAR_RECORDS_ ) {
+		} elsif ($item == &rVAR_RECORDS_ || $item == &zVAR_RECORDS_ ||
+                         $item == &rVAR_RECORDS_RENUMBER_ ||
+                         $item == &zVAR_RECORDS_RENUMBER_) {
 			my $Long1 = shift;
 			my $Long2 = shift;
 			$status = CDFlibll($operation, $item, $Long1, $Long2);
@@ -1335,6 +1345,67 @@ sub CDFgetValidate {
         return $validateX;
 }#end sub CDFgetValidate
 
+sub computeEPOCH {
+        my $year = shift;
+        my $month = shift;
+        my $day = shift;
+        my $hour = shift;
+        my $minute = shift;
+        my $second = shift;
+        my $milsec = shift;
+	if (ref($year) ne 'ARRAY') {
+          return computeEPOCHX ($year, $month, $day, $hour, $minute, $second,
+	     		        $milsec); 
+	} else {
+	  my @values;
+	  my @years = @$year;
+	  my @months = @$month;
+	  my @days = @$day;
+	  my @hours = @$hour;
+	  my @minutes = @$minute;
+	  my @seconds = @$second;
+	  my @milsecs = @$milsec;
+	  $#values = $#years;
+	  for (my $i = 0; $i <= $#years; $i++) {
+            $values[$i] = computeEPOCHX ($years[$i], $months[$i], $days[$i],
+					 $hours[$i], $minutes[$i], $seconds[$i],
+					 $milsecs[$i]);
+	  }
+          return @values;
+	}
+}#end sub computeEPOCH
+
+sub parseEPOCH {
+        use strict;
+        my $epochString = shift;
+	if (ref($epochString) ne 'ARRAY') {
+          return parseEPOCHX ($epochString);
+	} else {
+	  my @values;
+	  my @strs = @$epochString;
+	  $#values = $#strs;
+	  for (my $i = 0; $i <= $#strs; $i++) {
+            $values[$i] = parseEPOCHX ($strs[$i]);
+	  }
+          return @values;
+	}
+}#end sub parseEPOCH
+
+sub encodeEPOCH {
+        my $epoch = $_[0];
+	my $stra = $_[1];
+	if (ref($epoch) ne 'ARRAY') {
+          encodeEPOCHX ($epoch, $_[1]);
+	} else {
+	  my @t1 = @$epoch;
+	  my ($i, $astr);
+	  for ($i=0; $i <= $#t1; $i++) {
+            encodeEPOCHX ($t1[$i], $astr);
+	    $$stra[$i] = $astr;
+	  }
+	}
+}#end sub encodeEPOCH
+
 sub computeTT2000 {
         use strict;
         use Math::BigInt;
@@ -1347,33 +1418,78 @@ sub computeTT2000 {
         my $milsec = shift;
         my $micsec = shift;
         my $nansec = shift;
-        my $tt2000Str;
-        computeTT2000X ($year, $month, $day, $hour, $minute, $second, $milsec,
-                        $micsec, $nansec, $tt2000Str); 
-        my $tt2000 = Math::BigInt->new($tt2000Str);
-        return $tt2000;
+	if (ref($year) ne 'ARRAY') {
+          my $tt2000Str;
+          computeTT2000X ($year, $month, $day, $hour, $minute, $second, $milsec,
+                          $micsec, $nansec, $tt2000Str); 
+          return Math::BigInt->new($tt2000Str);
+	} else {
+	  my @values;
+	  my @years = @$year;
+	  my @months = @$month;
+	  my @days = @$day;
+	  my @hours = @$hour;
+	  my @minutes = @$minute;
+	  my @seconds = @$second;
+	  my @milsecs = @$milsec;
+	  my @micsecs = @$micsec;
+	  my @nansecs = @$nansec;
+	  $#values = $#years;
+	  my $value;
+	  for (my $i = 0; $i <= $#years; $i++) {
+            computeTT2000X ($years[$i], $months[$i], $days[$i], $hours[$i],
+			    $minutes[$i], $seconds[$i], $milsecs[$i],
+                            $micsecs[$i], $nansecs[$i], $value); 
+            $values[$i] = Math::BigInt->new($value);
+	  }
+          return @values;
+	}
 }#end sub computeTT2000
 
 sub parseTT2000 {
         use strict;
         use Math::BigInt;
         my $tt2000String = shift;
-        my $tt2000Str;
-        parseTT2000X ($tt2000String, $tt2000Str);
-        my $tt2000 = Math::BigInt->new($tt2000Str);
-        return $tt2000;
+	if (ref($tt2000String) ne 'ARRAY') {
+          my $tt2000Str;
+          parseTT2000X ($tt2000String, $tt2000Str);
+          my $tt2000 = Math::BigInt->new($tt2000Str);
+          return $tt2000;
+	} else {
+	  my @values;
+	  my @strs = @$tt2000String;
+	  $#values = $#strs;
+	  my $value;
+	  for (my $i = 0; $i <= $#strs; $i++) {
+            parseTT2000X ($strs[$i], $value);
+            $values[$i] = Math::BigInt->new($value);
+	  }
+          return @values;
+	}
 }#end sub parseTT2000
 
 sub encodeTT2000 {
         use strict;
         my $tt2000 = $_[0];
+	my $stra = $_[1];
         my $format;
         if (scalar(@_) == 3) {
           $format = $_[2];
         } else {
           $format = 3;
         }
-        encodeTT2000X ($tt2000, $_[1], $format);
+	if (ref($tt2000) ne 'ARRAY') {
+          encodeTT2000X ($tt2000, $_[1], $format);
+	} else {
+	  my @t1 = @$tt2000;
+	  # my @t2 = @$stra;
+	  # $#t2 = $#t1;
+	  my ($i, $astr);
+	  for ($i=0; $i <= $#t1; $i++) {
+            encodeTT2000X ($t1[$i], $astr, $format);
+	    $$stra[$i] = $astr;
+	  }
+	}
 }#end sub encodeTT2000
 
 sub leapsecondsinfo {
