@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF				CDF Header file for C/C++ applications.
 *
@@ -48,6 +53,10 @@
 *                               CDFgetVarRangeRecordsByVarName functions, and
 *                               a set of similar functions for put operations.
 *                               Added a new error message.
+*   V3.11 29-May-12, M Liu      Added CDFinsertVarRecordsByVarID and
+*                               CDFinsertVarRecorsByVarName.
+*   V3.12 28-May-14, M Liu      Added function items for record deletion:
+*                               r/zVAR__RECORDS_RENUMBER_.
 ******************************************************************************/
 
 #if !defined(CDFh_INCLUDEd__)
@@ -259,11 +268,9 @@ static double *TT2000NULL = 0;
 * Compression `4' used to be RICE.  Do not reuse! *
 **************************************************/
 #define GZIP_COMPRESSION		5L
-/* #define ZLIB_COMPRESSION                6L */
 
 #define RLE_OF_ZEROs			0L
 #define OPTIMAL_ENCODING_TREES		0L
-/* #define ZLIB_OF_ZEROs                   0L */
 #define NO_SPARSEARRAYS			0L
 #define NO_SPARSERECORDS		0L
 #define PAD_SPARSERECORDS		1L
@@ -429,7 +436,9 @@ static double *TT2000NULL = 0;
 #define IS_A_NETCDF                     ((CDFstatus) (-2228))
 #define TT2000_TIME_ERROR               ((CDFstatus) (-2229))
 #define UNABLE_TO_PROCESS_CDF           ((CDFstatus) (-2230))
-/* #define ZLIB_DECOMPRESSION_ERROR        ((CDFstatus) (-2231)) */
+#define ZLIB_COMPRESS_ERROR             ((CDFstatus) (-2231))
+#define ZLIB_UNCOMPRESS_ERROR           ((CDFstatus) (-2232))
+#define CANNOT_INSERT_RECORDS           ((CDFstatus) (-2233))
 
 /******************************************************************************
 * Functions (for INTERNAL interface).
@@ -617,6 +626,8 @@ static double *TT2000NULL = 0;
 #define STAGE_CACHESIZE_	154L
 #define COMPRESS_CACHESIZE_	155L
 #define CDF_CHECKSUM_           156L
+#define rVAR_RECORDS_RENUMBER_	157L
+#define zVAR_RECORDS_RENUMBER_	158L
 
 #define CDFwithSTATS_		200L	/* For CDF internal use only! */
 #define CDF_ACCESS_		201L	/* For CDF internal use only! */
@@ -757,6 +768,9 @@ CDFgetAttrEntryNumElements(id,3,attrNum,entryNum,numElems)
 #define CDFdeletezVarRecords(id,varNum,sRec,eRec) \
 CDFdeleteVarRecords(id,1,varNum,sRec,eRec)
 
+#define CDFdeletezVarRecordsRenumber(id,varNum,sRec,eRec) \
+CDFdeleteVarRecordsRenumber(id,1,varNum,sRec,eRec)
+
 #define CDFgetzVarName(id,varNum,varName) \
 CDFgetVarName(id,1,varNum,varName)
 
@@ -879,6 +893,11 @@ CDFgetVarRangeRecordsByVarID(id,1,varNum,startRec,stopRec,buffer)
 #define CDFputzVarRangeRecordsByVarID(id,varNum,startRec,stopRec,buffer) \
 CDFputVarRangeRecordsByVarID(id,1,varNum,startRec,stopRec,buffer)
 
+#define CDFinsertzVarRecordsByVarID(id,varNum,startRec,numRecs,buffer) \
+CDFinsertVarRecordsByVarID(id,1,varNum,startRec,numRecs,buffer)
+#define CDFinsertrVarRecordsByVarID(id,varNum,startRec,numRecs,buffer) \
+CDFinsertVarRecordsByVarID(id,0,varNum,startRec,numRecs,buffer)
+
 /*
  * CLOSE_  *
  *         */
@@ -1049,6 +1068,13 @@ CDFlib (SELECT_, CDF_, id, \
         DELETE_, (zVar? zVAR_RECORDS_: rVAR_RECORDS_), firstRec, lastRec, \
         NULL_)
 
+#define CDFdeleteVarRecordsRenumber(id,zVar,varNum,firstRec,lastRec) \
+CDFlib (SELECT_, CDF_, id, \
+                 (zVar? zVAR_: rVAR_), varNum, \
+        DELETE_, (zVar? zVAR_RECORDS_RENUMBER_: rVAR_RECORDS_RENUMBER_), \
+                  firstRec, lastRec, \
+        NULL_)
+
 /*
  * GET_ *
  *      */
@@ -1714,7 +1740,17 @@ VISIBLE_PREFIX CDFstatus CDFgetVarRangeRecordsByVarName PROTOARGs((
   CDFid id, char *varName, long startRec, long stopRec, void *buffer
 ));
 VISIBLE_PREFIX CDFstatus CDFputVarRangeRecordsByVarName PROTOARGs((
-  CDFid id, char *varName, long startRec,long stopRec, void *buffer
+  CDFid id, char *varName, long startRec, long stopRec, void *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFinsertVarRecordsByVarID PROTOARGs((
+  CDFid id, int zVar, long varNum, long startRec,long numRecs,
+  void *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFinsertVarRecordsByVarName PROTOARGs((
+  CDFid id, char *varName, long startRec, long numRecs, void *buffer
+));
+VISIBLE_PREFIX CDFstatus CDFdeleteRecordsForAll PROTOARGs((
+  CDFid id, long startRec, long endRec
 ));
 VISIBLE_PREFIX void CDFsetFileBackward PROTOARGs((
   int flag
@@ -1732,6 +1768,12 @@ VISIBLE_PREFIX int CDFgetFileBackwardEnvVar PROTOARGs(());
 VISIBLE_PREFIX void CDFsetValidate PROTOARGs((long mode));
 VISIBLE_PREFIX int CDFgetValidate PROTOARGs(());
 VISIBLE_PREFIX int CDFgetValidateDebug PROTOARGs(());
+VISIBLE_PREFIX void ROWtoCOL PROTOARGs((
+  void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
+));
+VISIBLE_PREFIX void COLtoROW PROTOARGs((
+  void *iBuffer, void *oBuffer, long numDims, long dimSizes[], long nValueBytes
+));
 #if !defined(__CFM68K__) || defined(__USING_STATIC_LIBS__) || !defined(CFM68KDLL)
 VISIBLE_PREFIX void EPOCHbreakdown PROTOARGs((
   double epoch, long *year, long *month, long *day, long *hour, long *minute,
