@@ -45,8 +45,8 @@
 use strict;
 use Math::BigInt;
 
-BEGIN { unshift @INC,'/home/liu/PerlCDF34_1/blib/arch',
-                     '/home/liu/PerlCDF34_1/blib/lib'; }
+BEGIN { unshift @INC,'/home/cdf/PerlCDF35_1/blib/arch',
+                     '/home/cdf/PerlCDF35_1/blib/lib'; }
 use CDF;
 
 my $N_DIMS = 2;
@@ -60,6 +60,8 @@ my $zNUM_ELEMSa = 8;
 my $encoding = NETWORK_ENCODING;
 my $actual_encoding = NETWORK_ENCODING;
 my $majority = ROW_MAJOR;
+my $compression = GZIP_COMPRESSION;
+my @compressionLevel = (6);
 my $numDims = $N_DIMS;
 my @dimSizes = ( $DIM_0_SIZE, $DIM_1_SIZE );
 my $zNumDimsA = $zN_DIMSa;
@@ -168,6 +170,7 @@ my $id; my $status;
 $status = CDF::CDFlib(CREATE_, CDF_, "TEST",$numDims,\@dimSizes,\$id,
 	   	      PUT_, CDF_ENCODING_, $encoding,
  			    CDF_MAJORITY_, $majority,
+ 			    CDF_COMPRESSION_, $compression, \@compressionLevel,
  		      NULL_);
 if ($status < CDF_OK) {
   if ($status == CDF_EXISTS) {
@@ -182,6 +185,8 @@ if ($status < CDF_OK) {
     $status = CDF::CDFlib (CREATE_, CDF_, "TEST", $numDims, \@dimSizes, \$id,
 			   PUT_, CDF_ENCODING_, $encoding,
 				 CDF_MAJORITY_, $majority,
+ 			         CDF_COMPRESSION_, $compression,
+						   \@compressionLevel,
 		    	   NULL_);
     QuitCDF ("1.2", $status) if ($status < CDF_OK) ;
   }
@@ -285,13 +290,14 @@ QuitCDF ("5.0", $status) if ($status < CDF_OK) ;
 $status = CDF::CDFlib (CREATE_, CDF_, "TEST", $numDims, \@dimSizes, \$id,
 		       PUT_, CDF_ENCODING_, $encoding,
 			     CDF_MAJORITY_, $majority,
+ 			     CDF_COMPRESSION_, $compression, \@compressionLevel,
 		       NULL_);
 QuitCDF ("6.0", $status) if ($status < CDF_OK) ;
 
 # Uncomment the following lines if MD5 checksum option is needed.
-#$status = CDF::CDFlib (PUT_, CDF_CHECKSUM_, MD5_CHECKSUM,
-#                       NULL_);
-#QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
+$status = CDF::CDFlib (PUT_, CDF_CHECKSUM_, MD5_CHECKSUM,
+                       NULL_);
+QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
 # Or, use this way:
 #$status = CDF::CDFsetChecksum ($id, MD5_CHECKSUM);
 #QuitCDF ("6.1", $status) if ($status < CDF_OK) ;
