@@ -37,8 +37,8 @@
 use strict;
 use Math::BigInt;
 
-BEGIN { unshift @INC,'/home/liu/PerlCDF34_1/blib/arch',
-                     '/home/liu/PerlCDF34_1/blib/lib'; }
+BEGIN { unshift @INC,'/home/cdf/PerlCDF35_1/blib/arch',
+                     '/home/cdf/PerlCDF35_1/blib/lib'; }
 use CDF;
 
 my $N_DIMS = 2;
