@@ -24,8 +24,8 @@
 use strict;
 use Math::BigInt;
 
-BEGIN { unshift @INC,'/home/liu/PerlCDF33_2/blib/arch',
-                     '/home/liu/PerlCDF33_2/blib/lib'; }
+BEGIN { unshift @INC,'/home/cdf/PerlCDF35_1/blib/arch',
+                     '/home/cdf/PerlCDF35_1/blib/lib'; }
 use CDF;
 
 #############################################################################
