@@ -18,8 +18,8 @@
 
 use strict;
 
-BEGIN { unshift @INC,'/Users/liu/PerlCDF33_1/blib/arch',
-                     '/Users/liu/PerlCDF33_1/blib/lib'; }
+BEGIN { unshift @INC,'/Users/cdf/PerlCDF35_1/blib/arch',
+                     '/Users/cdf/PerlCDF35_1/blib/lib'; }
 use CDF;
 
 my $file = $ARGV[0];
